@@ -15,9 +15,15 @@ class SweepAlgorithm(GeneralEvolutionaryAlgorithm):
     def run(self):
         t_s = time.time()
 
-        # create initial population and evaluate individuals
-        population = self.gen_initial_population()
-        self.evaluate(population.individuals)
+        # create initial population
+        individuals = self.generator.generate()
+
+        # append to problem
+        for individual in individuals:
+            self.problem.individuals.append(individual)
+
+        # evaluate individuals
+        self.evaluate(individuals)
 
         t = time.time() - t_s
         self.problem.logger.info("Sweep: elapsed time: {} s".format(t))
