@@ -50,7 +50,7 @@ class TestDataStoreSqlite(unittest.TestCase):
         algorithm = NSGAII(problem)
         algorithm.options['max_population_number'] = 3
         algorithm.options['max_population_size'] = 4
-        algorithm.options['max_processes'] = 1
+        algorithm.options['max_processes'] = 4
         algorithm.run()
 
         # cache individuals
@@ -64,7 +64,6 @@ class TestDataStoreSqlite(unittest.TestCase):
         # check json
         conn = sqlite3.connect(database_name)
         c = conn.cursor()
-        print(list(individuals.keys())[6])
         c.execute("SELECT * FROM individuals WHERE ID = ?", [list(individuals.keys())[6]])
         row = c.fetchall()
         individual = Individual.from_dict(json.loads(row[0][1]))
@@ -84,15 +83,16 @@ class TestDataStoreSqlite(unittest.TestCase):
         self.assertEqual(problem.name, 'NLopt_BOBYQA')
 
         individuals = problem.last_population()
-        self.assertAlmostEqual(individuals[0].vector[1], -0.412096, 4)
-        self.assertAlmostEqual(individuals[1].vector[0], 0.26419, 4)
-        self.assertAlmostEqual(individuals[0].costs[0], 0.218191, 4)
+        self.assertAlmostEqual(problem.parameters['x_1']['bounds'][0], -10)
+        self.assertAlmostEqual(individuals[0].vector[1], 6.58962945, 4)
+        self.assertAlmostEqual(individuals[1].vector[0], 1.8944488, 4)
+        self.assertAlmostEqual(individuals[0].costs[0], 49.0245242, 4)
 
 
 class TestDataStoreBenchmark(unittest.TestCase):
     def setUp(self):
         self.n = 300
-        self.max_processes = 5
+        self.max_processes = 10
 
     def test_benchmark_sqlite_data_store(self):
         t_s = time.time()
